@@ -1,4 +1,5 @@
 """This module pulls together this package: create and parse CLI arguments for tox."""
+
 from __future__ import annotations
 
 import os
@@ -51,7 +52,7 @@ def _get_base(args: Sequence[str]) -> tuple[int, ToxHandler, Source]:
         ...  # ignore parse errors, such as -va raises ignored explicit argument 'a'
     guess_verbosity = parsed.verbosity
     handler = setup_report(guess_verbosity, parsed.is_colored)
-    from tox.plugin.manager import MANAGER  # load the plugin system right after we set up report
+    from tox.plugin.manager import MANAGER  # load the plugin system right after we set up report  # noqa: PLC0415
 
     source = discover_source(parsed.config_file, parsed.root_dir)
 
@@ -71,7 +72,7 @@ def _get_all(args: Sequence[str]) -> tuple[Parsed, dict[str, Callable[[State], i
 def _get_parser() -> ToxParser:
     tox_parser = ToxParser.core()  # load the core options
     # plus options setup by plugins
-    from tox.plugin.manager import MANAGER
+    from tox.plugin.manager import MANAGER  # noqa: PLC0415
 
     MANAGER.tox_add_option(tox_parser)
     tox_parser.fix_defaults()
@@ -80,7 +81,7 @@ def _get_parser() -> ToxParser:
 
 def _get_parser_doc() -> ToxParser:
     # trigger register of tox env types (during normal run we call this later to handle plugins)
-    from tox.plugin.manager import MANAGER  # pragma: no cover
+    from tox.plugin.manager import MANAGER  # pragma: no cover  # noqa: PLC0415
 
     MANAGER.load_plugins(Path.cwd())
 
